==> shardingsphere-infra-common-5.0.0-sources.jar: org/apache/shardingsphere/infra/metadata/schema/QualifiedSchema.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.infra.metadata.schema;

import com.google.common.base.Splitter;
import lombok.Getter;
import lombok.RequiredArgsConstructor;
import org.apache.shardingsphere.infra.database.DefaultSchema;

import java.util.List;

/**
 * Qualified schema.
 */
@RequiredArgsConstructor
@Getter
public final class QualifiedSchema {
    
    private static final String DELIMITER = ".";
    
    private final String schemaName;
    
    private final String dataSourceName;
    
    public QualifiedSchema(final String value) {
        if (value.contains(DELIMITER)) {
            List<String> values = Splitter.on(DELIMITER).splitToList(value);
            schemaName = values.get(0);
            dataSourceName = values.get(1);
        } else {
            schemaName = DefaultSchema.LOGIC_NAME;
            dataSourceName = value;
        }
    }
    
    @Override
    public String toString() {
        return String.join(DELIMITER, schemaName, dataSourceName);
    }
}

==> shardingsphere-infra-common-5.1.1-sources.jar: org/apache/shardingsphere/infra/metadata/schema/QualifiedSchema.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.infra.metadata.schema;

import com.google.common.base.Splitter;
import lombok.Getter;
import lombok.RequiredArgsConstructor;

import java.util.List;

/**
 * Qualified schema.
 */
@RequiredArgsConstructor
@Getter
public final class QualifiedSchema {
    
    private static final String DELIMITER = ".";
    
    private final String schemaName;
    
    private final String groupName;
    
    private final String dataSourceName;
    
    public QualifiedSchema(final String value) {
        List<String> values = Splitter.on(DELIMITER).splitToList(value);
        schemaName = values.get(0);
        groupName = values.get(1);
        dataSourceName = values.get(2);
    }
    
    @Override
    public String toString() {
        return String.join(DELIMITER, schemaName, groupName, dataSourceName);
    }
}
